#
# spec file for package libqt5-qtconnectivity
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Internal QML import of examples
%global __requires_exclude qmlimport\\(Shared.*

%define qt5_snapshot 1
%define libname libQt5Bluetooth5
%define base_name libqt5
%define real_version 5.15.15
%define so_version 5.15.15
%define tar_version qtconnectivity-everywhere-src-%{version}
Name:           libqt5-qtconnectivity
Version:        5.15.15+kde3
Release:        1.1
Summary:        Qt 5 Nfc Addon
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/X11
URL:            https://www.qt.io
Source:         %{tar_version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  fdupes
BuildRequires:  libqt5-qtbase-devel >= %{real_version}
BuildRequires:  libqt5-qtbase-private-headers-devel >= %{real_version}
BuildRequires:  libqt5-qtdeclarative-private-headers-devel >= %{real_version}
%if %{qt5_snapshot}
#to create the forwarding headers
BuildRequires:  perl
%endif
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(bluez)

%description
Qt is a set of libraries for developing applications.

%prep
%autosetup -p1 -n %{tar_version}

%package -n %{libname}
Summary:        Qt 5 Bluez Addon
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/X11
%requires_ge    libQt5DBus5
Recommends:     %{name}-tools

%description -n %{libname}
Qt is a set of libraries for developing applications.

%package -n libQt5Nfc5
Summary:        Qt 5 Nfc Addon
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/X11
%requires_ge    libQt5Core5

%description -n libQt5Nfc5
Qt is a set of libraries for developing applications.

%package -n %{libname}-imports
Summary:        Qt 5 Bluez Addon
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/X11
%requires_ge    libQtQuick5
Supplements:    (%{libname} and libQtQuick5)
# imports splited with 5.4.1
Conflicts:      %{libname} < 5.4.1

%description -n %{libname}-imports
Qt is a set of libraries for developing applications.

%package -n libQt5Nfc5-imports
Summary:        Qt 5 Nfc Addon
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/X11
%requires_ge    libQtQuick5
Supplements:    (libQt5Nfc5 and libQtQuick5)
# imports splited with 5.4.1
Conflicts:      libQt5Nfc5 < 5.4.1

%description -n libQt5Nfc5-imports
Qt is a set of libraries for developing applications.

%package tools
Summary:        Qt 5 Nfc Addon
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/X11

%description tools
Qt is a set of libraries for developing applications.

%package devel
Summary:        Qt Development Kit
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/X11
Requires:       %{libname} = %{version}
Requires:       libQt5Nfc5 = %{version}

%description devel
You need this package, if you want to compile programs with qtsensors.

%package private-headers-devel
Summary:        Non-ABI stable experimental API
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}
Requires:       libqt5-qtbase-private-headers-devel
Requires:       libqt5-qtdeclarative-private-headers-devel
BuildArch:      noarch

%description private-headers-devel
This package provides private headers of libqt5-qtsensors that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package examples
Summary:        Qt5 location examples
License:        BSD-3-Clause
Group:          Development/Libraries/X11
Recommends:     %{name}-devel

%description examples
Examples for libqt5-qtconnectivity module.

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig
%post -n libQt5Nfc5 -p /sbin/ldconfig
%postun -n libQt5Nfc5 -p /sbin/ldconfig

%build
%if %{qt5_snapshot}
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif
rm -rfv src/tools/sdpscanner/qt_attribution.json
%qmake5
%make_jobs

%install
%qmake5_install
find %{buildroot}/%{_libdir} -type f -name '*la' -print -exec perl -pi -e 's, -L%{_builddir}/\S+,,g' {} \;
find %{buildroot}/%{_libdir}/pkgconfig -type f -name '*pc' -print -exec perl -pi -e 's, -L%{_builddir}/\S+,,g' {} \;
# kill .la files
rm -f %{buildroot}%{_libqt5_libdir}/lib*.la

# Link all the binaries with -qt5 suffix to %{_bindir}
mkdir -p %{buildroot}%{_bindir}
pushd %{buildroot}%{_libqt5_bindir}
for i in * ; do
      # No conflict with Qt4, so keep the original name for compatibility
      ln -s %{_libqt5_bindir}/$i %{buildroot}%{_bindir}/${i}
      ln -s %{_libqt5_bindir}/$i %{buildroot}%{_bindir}/${i}-qt5
done
popd

%files -n %{libname}
%defattr(-,root,root,755)
%license LICENSE.*
%{_libqt5_libdir}/libQt5Bluetooth.so.*

%files -n %{libname}-imports
%defattr(-,root,root,755)
%license LICENSE.*
%{_libqt5_archdatadir}/qml/QtBluetooth/

%files -n libQt5Nfc5
%defattr(-,root,root,755)
%license LICENSE.*
%{_libqt5_libdir}/libQt5Nfc.so.*

%files -n libQt5Nfc5-imports
%defattr(-,root,root,755)
%license LICENSE.*
%{_libqt5_archdatadir}/qml/QtNfc/

%files private-headers-devel
%defattr(-,root,root,755)
%license LICENSE.*
%{_libqt5_includedir}/QtNfc/%{so_version}
%{_libqt5_includedir}/QtBluetooth/%{so_version}

%files devel
%defattr(-,root,root,755)
%license LICENSE.*
%exclude %{_libqt5_includedir}/QtNfc/%{so_version}
%exclude %{_libqt5_includedir}/QtBluetooth/%{so_version}
%{_libqt5_includedir}/QtNfc
%{_libqt5_includedir}/QtBluetooth
%{_libqt5_libdir}/cmake/Qt5Bluetooth/
%{_libqt5_libdir}/cmake/Qt5Nfc/
%{_libqt5_libdir}/libQt5Bluetooth.prl
%{_libqt5_libdir}/libQt5Nfc.prl
%{_libqt5_libdir}/libQt5Bluetooth.so
%{_libqt5_libdir}/libQt5Nfc.so
%{_libqt5_libdir}/pkgconfig/Qt5Bluetooth.pc
%{_libqt5_libdir}/pkgconfig/Qt5Nfc.pc
%{_libqt5_libdir}/qt5/mkspecs/modules/qt_lib_*.pri

%files tools
%defattr(-,root,root,755)
%license LICENSE.*
%{_bindir}/sdpscanner*
%{_libqt5_bindir}/sdpscanner*

%files examples
%defattr(-,root,root,755)
%license LICENSE.*
%{_libqt5_examplesdir}/

%changelog
* Wed Sep  4 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.15+kde3, rebased upstream:
  * [docs] QBluetoothAddress: fix a grammer mistake
  * Bump version to 5.15.15
* Wed May 29 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.14+kde3, rebased upstream:
  * Android-example: add missing properties in AndroidManifest.xml
  * Bump version to 5.15.14
* Tue Mar 19 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.13+kde4, rebased upstream:
  * Doc: Replace dead link to external neard page
  * Bump version to 5.15.13
* Fri Dec 29 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.12+kde6, rebased upstream:
  * Bump version to 5.15.12
* Fri Oct  6 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.11+kde6, rebased upstream:
  * Fix bluetooth service discovery not finishing on Android
  * Add a timeout guard for Android BT device discovery not starting
  * Repair tst_QBluetoothDeviceDiscoveryAgent unit test on Android
* Thu Sep 28 2023 Fabian Vogt <fvogt@suse.com>
- Update to version 5.15.10+kde6:
  * Fix translation context of QBluetoothUuid::WeightScaleFeature
  * QBluetoothUuid: remove default case labels and fix the fallout
* Tue Jun 13 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.10+kde4, rebased upstream:
  * Update LGPL license header
  * Replace deprecated bluetooth disable/enable methods on Android
  * includemocs
  * QLeAdvertizerBluez: add missing Q_OBJECT macro
  * Rename qleadvertiser_p.h → qleadvertiser_bluez_p.h
  * QtConnectivity: replace qSwap with std::swap/member-swap where possible
  * Fix crash when service discovery agent (SDA) is stopped on Android
  * QLowEnergyControllerPrivateAndroid: remove unused forward declaration
  * Improve Android-12 bluetooth permission error reporting
  * Update BT LE peripheral role OS support documentation
  * Introduce Android 12 / SDK 31+ bluetooth permissions
  * tst_qbluetoothservicediscovery: make auto-test less evil
  * Remove QBluetoothSocket::connected double-emit on macOS
  * Fix Android bluetooth server assert when disposed of quickly
* Fri Apr 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde34, rebased upstream:
  * Close socket descriptor when QBluetoothSocketBluez is destroyed
  * Fix Bluez BT LE battery reading
  * Repair tst_QBluetoothDeviceDiscoveryAgent on Android
  * Accommodate different bluez socket types in autotest [secFlags]
  * Improve bluetooth service discovery on macOS Monterey
  * Avoid multiple client sockets in pingpong bluetooth example
  * IOBluetooth: tweak a couple of classes
  * Fix missing MetaType registration
  * Improve macOS classic bluetooth (server) SDP record creation
  * IOBluetooth: fix SDP inquiry broken by Monterey
  * Windows BT: reverse the latter UUID part to correct order
  * Document the bluetooth socket data pausing on macOS Monterey
  * Decrement the pending paired device counter only once per device
  * Make Windows bluetooth to scan all found devices for services
  * PingPong example: let the parent QObject do the cleanup
  * Android: fix signal order during service discovery
  * Store the serviceinfo in pingpong example
  * tst_QBluetoothServiceInfo::tst_assignment - fix for Monterey
  * IOBluetooth (device scan) - reduce the manual timeout
  * Android BT LE Client thread protection improvement
  * Windows QBluetoothSocket: fix crash at disconnecting
  * Add Info.plists to autotests which require bluetooth usage key
  * Windows QBluetoothSocket: remove unneeded variable from SocketWorker
  * QLowEnergyController Windows: fix early disconnect crash on Win 11
* Thu Mar 16 2023 Fabian Vogt <fvogt@suse.com>
- Update to version 5.15.8+kde8:
  * SDP scanner: encode input URLs and escape XML-specific characters
  * sdpscanner: fix URL processing
  * sdpscanner: fix potential unwanted truncation for SDP_TEXT_STR{8,16,32}
* Mon Jan  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde5, rebased upstream:
  * QBluetoothSocket Windows: check that host info is available
  * Thread protection for Android BT LE Server
  * QBluetoothSocket Windows: fix localAddress and peerAddress
  * QBluetoothSocket Windows: actually query remote port
  * NFC: Fix PendingIntent creation for Android 12
  * CoreBluetooth: fix warning message concatenation
  * Windows: fix object destruction order when terminating helper threads
  * Bluetooth (Darwin): bail out early, if Info.plist is missing
  * Fix thread affinity for charListObtained slot
  * Fix BT LE service addition timing issue on Android
  * macOS specific Info.plist file for Bluetooth Examples
  * IOBluetooth: avoid over-retaining Obj-C entity
* Thu Nov  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.7+kde5, rebased upstream:
  * Refactor characteristics read for WinRT
  * QLowEnergyControllerWinRT: refactor connection to device
  * Move connecting to a LE device to background on Windows
  * QLowEnergyController(WinRT): introduce timeout for connection
  * winrt: Protect from late AdvertisementReceived callback
  * IOBluetoothDeviceInquiry: manually interrupt Classic scan
  * QtBluetooth (examples): add Info.plist for iOS
  * CoreBluetooth: provide a description (in Info.plist) of BT usage
  * Bluetooth docs: mention the Apple's specific requirements
  * Heart-rate example: add a proper Info.plist
  * Android: Call handleTargetLost directly on NFC TagLostException
* Mon Sep 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.6+kde5, rebased upstream:
  * Doc: Fix typo
  * QWinRTBluetoothDeviceDiscoveryWorker: Add error handling
  * Improve detection of enabled location service on SDK<28
* Mon Jun 27 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.5+kde5, rebased upstream:
  * Add QIODevice::canReadLine call to QBluetoothSocket
  * Handle LE enhanced connection complete in Bluez peripheral
  * Keep the bluetooth service name if the remote has provided it
  * Use the service's socket protocol info on Bluez bluetooth socket
  * Fix Linux bluetooth service discovery crash with multiple services
  * Fix "loop variable creates a copy" warning
  * Prefer QChar over QString that consists of a single QChar
  * CoreBluetooth: add a workaround to enable using scan options
  * Backport a fix from Qt 6 (stop using a deprecated API)
  * Revert "Update commercial license headers"
  * Fix bug: Let QBluetoothsocket::close emit disconnected only once
  * Change tst_qlowenergycontroller to wait for disconnects
  * Update commercial license headers
- Drop 0001-Revert-Bump-version.patch, it's versioned correctly now
* Fri Jan 21 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.2+kde5:
  * Always call setOpenMode before setSocketState
  * Add server role to BlueZ service registration
  * Fix error handling in BlueZ connectToServiceHelper
  * Correct error handling in QLowEnergyControllerPrivateBluezDBUS
* Tue Jun 22 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Switch to KDE's maintenance branch
- Update to version 5.15.2+kde1:
  * Bump version
- Add patch to reset version to 5.15.2:
  * 0001-Revert-Bump-version.patch
* Sat Jan 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add compatibility with qml-autoreqprov
* Fri Nov 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.2:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtconnectivity.git/plain/dist/changes-5.15.2/?h=5.15.2
* Thu Sep 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtconnectivity.git/plain/dist/changes-5.15.1/?h=5.15.1
* Tue May 26 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0:
  * No changelog available
* Thu May 21 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0-rc2:
  * No changelog available
* Wed May  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-rc:
  * New bugfix release
  * For the changes between 5.14.2 and 5.15.0 please see:
    http://code.qt.io/cgit/qt/qtconnectivity.git/plain/dist/changes-5.15.0/?h=5.15.0
* Fri Apr 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta4:
  * New bugfix release
  * No changelog available
* Tue Apr 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta3:
  * New bugfix release
  * No changelog available
* Tue Mar 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Feb 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta1:
  * New bugfix release
  * No changelog available
* Wed Feb 19 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-alpha:
  * New feature release
  * For more details please see:
    https://wiki.qt.io/New_Features_in_Qt_5.15
* Mon Jan 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtconnectivity.git/plain/dist/changes-5.14.1/?h=v5.14.1
* Tue Dec 17 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update the license tags.
* Thu Dec 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0:
  * New bugfix release
  * For the changes between 5.13.2 and 5.14.0 please see:
    https://code.qt.io/cgit/qt/qtconnectivity.git/tree/dist/changes-5.14.0?h=v5.14.0
  * For the changes between 5.13.1 and 5.13.2 please see:
    https://code.qt.io/cgit/qt/qtconnectivity.git/tree/dist/changes-5.13.2?h=v5.14.0
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-rc:
  * New bugfix release
  * No changelog available
  * For more details please see:
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta3:
  * New bugfix release
  * No changelog available
* Thu Oct 24 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta2:
  * New bugfix release
  * No changelog available
* Tue Oct 15 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta1:
  * New bugfix release
  * No changelog available
* Mon Sep 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-alpha:
  * New feature release
  * No changelog available
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Fri Sep  6 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.13.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtconnectivity.git/plain/dist/changes-5.13.1/?h=v5.13.1
* Wed Jul  3 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Link from Qt bindir into %%_bindir, not the other way around to fix
  applicationDirPath called from Qt binaries
- Add -qt5 suffix to all binaries in %%_bindir
* Wed Jun 19 2019 fabian@ritter-vogt.de
- Update to 5.13.0:
  * New bugfix release
  * No changelog available
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtconnectivity.git/plain/dist/changes-5.13.0/?h=5.13
* Tue Jun  4 2019 fabian@ritter-vogt.de
- Update to 5.13.0-rc:
  * New bugfix release
  * No changelog available
* Mon Apr 29 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta2:
  * New bugfix release
  * No changelog available
* Thu Apr 18 2019 fabian@ritter-vogt.de
- Update to 5.12.3:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtconnectivity.git/plain/dist/changes-5.12.3/?h=v5.12.3
* Thu Mar 21 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta1:
  * New feature release
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtconnectivity.git/plain/dist/changes-5.13.0/?h=5.13
* Thu Mar 14 2019 fabian@ritter-vogt.de
- Update to 5.12.2:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtconnectivity.git/plain/dist/changes-5.12.2/?h=5.12.2
* Fri Feb  1 2019 fabian@ritter-vogt.de
- Update to 5.12.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtconnectivity.git/plain/dist/changes-5.12.1/?h=v5.12.1
* Thu Dec  6 2018 fabian@ritter-vogt.de
- Update to 5.12.0:
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtconnectivity.git/plain/dist/changes-5.12.0/?h=v5.12.0
* Mon Dec  3 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc2:
  * New bugfix release
  * Only important bugfixes
- Changelog for Qt 5.12.0:
  * http://code.qt.io/cgit/qt/qtconnectivity.git/plain/dist/changes-5.12.0/?h=5.12.0
* Thu Nov 22 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc:
  * New bugfix release
  * No changelog available
* Thu Nov  8 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta4:
  * New bugfix release
  * No changelog available
* Fri Oct 26 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta3:
  * New bugfix release
  * No changelog available
* Wed Oct 17 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta1:
  * New bugfix release
  * No changelog available
* Tue Oct  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0-alpha:
  * New feature release
  * For more details please see:
  * http://wiki.qt.io/New_Features_in_Qt_5.12
* Fri Sep 21 2018 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtconnectivity.git/plain/dist/changes-5.11.2/?h=v5.11.2
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtconnectivity.git/plain/dist/changes-5.11.1/?h=v5.11.1
* Tue May 22 2018 fabian@ritter-vogt.de
- Update to 5.11.0
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtconnectivity.git/plain/dist/changes-5.11.0/?h=v5.11.0
* Tue May  8 2018 fabian@ritter-vogt.de
- Update to 5.11.0-rc
  * New bugfix release
  * No changelog available
* Mon Apr 23 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta4
  * New bugfix release
  * No changelog available
* Wed Apr 11 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta3
  * New bugfix release
  * No changelog available
* Wed Mar 28 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta2
  * New bugfix release
  * No changelog available
* Tue Mar 13 2018 christophe@krop.fr
- Fix the license tag.
* Thu Mar  1 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta1
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtconnectivity.git/plain/dist/changes-5.11.0-beta1/?h=v5.11.0-beta1
* Tue Feb 20 2018 fabian@ritter-vogt.de
- Update to 5.11.0-alpha
  * New feature release
  * For more details please see:
  * https://wiki.qt.io/New_Features_in_Qt_5.11
* Wed Feb 14 2018 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtconnectivity.git/plain/dist/changes-5.10.1/?h=v5.10.1
* Fri Dec  8 2017 christophe@krop.fr
- Update the license tag (boo#967696)
* Thu Dec  7 2017 fabian@ritter-vogt.de
- Update to 5.10.0 final
  * New bugfix release
* Sun Dec  3 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 2
  * New bugfix release
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 1
  * New bugfix release
* Sat Nov 25 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details, see:
    http://code.qt.io/cgit/qt/qtconnectivity.git/tree/dist/changes-5.9.3/?h=v5.9.3
* Wed Nov 15 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 4
- Contains bugfixes
* Thu Nov  2 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 3
- Contains bugfixes
* Mon Oct 30 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 2
- Contains bugfixes
* Mon Oct  9 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 1
- For more information visit:
    https://blog.qt.io/blog/2017/10/09/qt-5-10-beta-released/
* Sun Oct  8 2017 lbeltrame@kde.org
- Update to 5.9.2
  * For more details please see:
    https://blog.qt.io/blog/2017/10/06/qt-5-9-2-released/
* Mon Sep 25 2017 fabian@ritter-vogt.de
- Update to 5.10 Alpha 1
- For more information visit:
    https://blog.qt.io/blog/2017/09/13/qt-5-10-alpha-released/
* Sat Jul  1 2017 lbeltrame@kde.org
- Update to 5.9.1
  * For more details please see:
    http://blog.qt.io/blog/2017/06/30/qt-5-9-1-released/
* Wed May 31 2017 fabian@ritter-vogt.de
- Update to 5.9.0 final
* Wed May 24 2017 fabian@ritter-vogt.de
- Update to 5.9.0 RC:
  * For more details please see:
    http://lists.qt-project.org/pipermail/announce/2017-May/000115.html
    and https://wiki.qt.io/New_Features_in_Qt_5.9
* Wed Dec 14 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * For more details please see:
    https://blog.qt.io/blog/2016/12/14/qt-5-7-1-released/
    and https://www.qt.io/qt5-7/
* Sat Sep 24 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.qt.io/qt5-7/
* Wed Jun  8 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * For more details please see:
    http://blog.qt.io/blog/2016/06/08/qt-5-6-1-released/
* Fri Mar 18 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    http://blog.qt.io/blog/2016/03/16/qt-5-6-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.6
* Fri Oct 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1
  * For more details please see:
    http://blog.qt.io/blog/2015/10/15/qt-5-5-1-released/
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * For more details please see:
    http://blog.qt.io/blog/2015/07/01/qt-5-5-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.5
* Wed Jun  3 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2
  * Bugfix release, for more details please see:
    http://blog.qt.io/blog/2015/06/02/qt-5-4-2-released/
- Drop endian.patch, merged upstream
* Tue Feb 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1
  * For more details please see:
    http://blog.qt.io/blog/2015/02/24/qt-5-4-1-released/
- Split the imports into separate package
- Add minimal requires on libQtQuick5, libQt5Core5 and libQt5DBus5
* Mon Feb 16 2015 schwab@suse.de
- endian.patch: Use proper endian conversion functions
  (https://codereview.qt-project.org/#/c/106263/)
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- Update to 5.4 Final
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/12/10/qt-5-4-released/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
* Thu Nov 27 2014 hrvoje.senjan@gmail.com
- Update to 5.4 RC
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/11/27/qt-5-4-release-candidate-available/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
* Fri Oct 17 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0 beta
  * New feature release, please see
  http://blog.qt.digia.com/blog/2014/10/17/qt-5-4-beta-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.4
* Mon Sep  8 2014 hrvoje.senjan@gmail.com
- Activate libqt5-qtconnectivity package
